/* --------------------------------------------------------------- */
/* DOGXL.h -- header file for DOGXL LCD displays                   */
/* --------------------------------------------------------------- */
/*                                                                 */
/* Copyright (c) Mike Cowlishaw, 2010-2012.  All rights reserved.  */
/*                                                                 */
/* Permission to use, copy, modify, and/or distribute this         */
/* software for any purpose with or without fee is hereby granted, */
/* provided that the above copyright notice and this permission    */
/* notice appear in all copies, and that notice and the date of    */
/* any modifications be added to the software.                     */
/*                                                                 */
/* This software is provided "as is".  No warranties, whether      */
/* express, implied, or statutory, including, but not limited to,  */
/* implied warranties of merchantability and fitness for a         */
/* particular purpose apply to this software.  The author shall    */
/* not, in any circumstances, be liable for special, incidental,   */
/* or consequential damages, for any reason whatsoever.            */
/*                                                                 */
/* --------------------------------------------------------------- */
/*                                                                 */
/* This includes:                                                  */
/*                                                                 */
/*   DOGXL 160x104 LCD screen and buffer definitions               */
/*                                                                 */
/*   UC1610 controller definitions                                 */
/*                                                                 */
/* --------------------------------------------------------------- */

#ifndef DOGXL_USED
#define DOGXL_USED

/* Screen and buffer definitions */

#define DOGTYPE DRAW_TYPE_GREY     // screen type
#define DOGX               160     // screen width
#define DOGY               104     // screen height
#define DOGZ                 2     // bits/pel

#define DOGXPITCH          433     // X dot pitch [um]
#define DOGYPITCH          412     // Y dot pitch [um]

#define DOGTIME        5300000     // estimated full write time
#define DOGPAGEX           160     // width of a page in bytes
#define DOGPAGES      (DOGY/4)     // number of pages
#define DOGBYTES ((DOGX*DOGY*DOGZ+7)/8) // buffer bytes, rounded up


/* Controller definitions */

// UC1610 7-bit addresses for I2C attachment
#define UC_CONTROL_ADDR       0x3c // A2 pin=0
#define UC_DATA_ADDR          0x3d // ..

#define UC_ALT_CONTROL_ADDR   0x3e // A2 pin=1
#define UC_ALT_DATA_ADDR      0x3f // ..


// UC1610 control sequences

// Read or write data read or write to the display RAM; note that the
// first byte of a read is a dummy byte.

// Status is always returned on a read from the Control address;
// These are the bits returned (bit 0 is always on)
#define UC_Status_ID         0x80    // 0b10000000  controller pin ID
#define UC_Status_MX         0x40    // 0b01000000  register LC[1], mirror X
#define UC_Status_MY         0x20    // 0b00100000  register LC[2], mirror Y
#define UC_Status_WA         0x10    // 0b00010000  AC[0]; wrap-around
#define UC_Status_DE         0x08    // 0b00001000  1 if display enabled
#define UC_Status_PM7        0x04    // 0b00000100  top two bits of Vbias
#define UC_Status_PM6        0x02    // 0b00000010  ..
#define UC_Status_1          0x01    // 0b00000001  always 1

// Commands are bytes written to the Control address (from datasheet
// Command Summary table):

#define UC_ColumnAddrLSB     0x00    // 0b00000000  ....xxxx   -> CA[3:0]
#define UC_ColumnAddrMSB     0x10    // 0b00010000  ....xxxx   -> CA[7:4]
#define UC_TempComp          0x24    // 0b00100100  ......xx   -> TC[1:0]
#define UC_PanelLoad         0x28    // 0b00101000  ......xx   -> PC[1:0]
#define UC_PumpControl       0x2c    // 0b00101100  ......xx   -> PC[3:2]
// (APC0/1 commands not for use)
#define UC_ScrollLineLSB     0x40    // 0b01000000  ....xxxx   -> SL[3:0]
#define UC_ScrollLineMSB     0x50    // 0b01010000  ....xxxx   -> SL[7:4]

#define UC_PageAddr          0x60    // 0b01100000  ...xxxxx   -> PA[4:0]
#define UC_Vbias             0x81    // 0b10000001  + xxxxxxxx -> PM[7:0]
#define UC_PartialControl    0x84    // 0b10000100  ......xx   -> LC[8:7]
#define UC_AddressControl    0x88    // 0b10001000  .....xxx   -> AC[2:0]
#define UC_FixedLines        0x90    // 0b10010000  ....xxxx   -> FL[3:0]
#define UC_LineRate          0xa0    // 0b10100000  ......xx   -> LC[4:3]
#define UC_AllPixelsOn       0xa4    // 0b10100100  .......x   -> DC[1]
#define UC_Inverse           0xa6    // 0b10100110  .......x   -> DC[0]
#define UC_Enable            0xae    // 0b10101110  .......x   -> DC[2]
#define UC_Mapping           0xc0    // 0b11000000  .....xxx   -> LC[2:0]
#define UC_GrayShade         0xd0    // 0b11010000  ......xx   -> LC[6:5]
#define UC_Reset             0xe2    // 0b11100010  (reset)
#define UC_NOP               0xe3    // 0b11100011  (nop)
// (Test control not for use)
#define UC_BiasRatio         0xe8    // 0b11101000  ......xx   -> BR[1:0]
#define UC_ResetCursorUpdate 0xee    // 0b11101110  AC[3]=0, CA=CR
#define UC_SetCursorUpdate   0xef    // 0b11101111  AC[3]=1, CR=CA
#define UC_COMend            0xf1    // 0b11110001  + .xxxxxxx -> CEN[6:0]
#define UC_DisplayStart      0xf2    // 0b11110010  + .xxxxxxx -> DST[6:0]
#define UC_DisplayEnd        0xf3    // 0b11110011  + .xxxxxxx -> DEN[6:0]
#define UC_WinStartColumn    0xf4    // 0b11110100  + xxxxxxxx -> WPC0[7:0]
#define UC_WinStartPage      0xf5    // 0b11110101  + ...xxxxx -> WPP0[4:0]
#define UC_WinEndColumn      0xf6    // 0b11110110  + xxxxxxxx -> WPC1[7:0]
#define UC_WinEndPage        0xf7    // 0b11110111  + ...xxxxx -> WPP1[4:0]
#define UC_WinEnable         0xf8    // 0b11111000  .......x   -> AC[4]

// COM is the number of row driver outputs used
// SEG is column drivers

#endif

